@@ -29,6 +29,7 @@ from pywink.devices.robot import WinkRobot
 from pywink.devices.scene import WinkScene
 from pywink.devices.light_group import WinkLightGroup
 from pywink.devices.binary_switch_group import WinkBinarySwitchGroup
+from pywink.devices.water_heater import WinkWaterHeater
 
 
 # pylint: disable=too-many-branches, too-many-statements
@@ -90,7 +91,7 @@ def build_device(device_state_as_json, api_interface):
     elif object_type == device_types.CAMERA:
         if device_state_as_json.get("device_manufacturer") == "canary":
             new_objects.append(WinkCanaryCamera(device_state_as_json, api_interface))
-        elif device_state_as_json.get("device_manufacturer") == "dropcam":
+        else:
             new_objects.extend(__get_subsensors_from_device(device_state_as_json, api_interface))
     elif object_type == device_types.AIR_CONDITIONER:
         new_objects.append(WinkAirConditioner(device_state_as_json, api_interface))
@@ -109,6 +110,8 @@ def build_device(device_state_as_json, api_interface):
             # This is a group of lights
             else:
                 new_objects.append(WinkLightGroup(device_state_as_json, api_interface))
+    elif object_type == device_types.WATER_HEATER:
+        new_objects.append(WinkWaterHeater(device_state_as_json, api_interface))
 
     return new_objects
 
@@ -144,16 +147,13 @@ def __get_outlets_from_powerstrip(item, api_interface):
 
 
 def __get_devices_from_piggy_bank(item, api_interface):
-    subdevices = []
-    subdevices.append(WinkPorkfolioBalanceSensor(item, api_interface))
-    subdevices.append(WinkPorkfolioNose(item, api_interface))
-    return subdevices
+    return [WinkPorkfolioBalanceSensor(item, api_interface),
+            WinkPorkfolioNose(item, api_interface)]
 
 
 def __get_sensors_from_smoke_detector(item, api_interface):
-    sensors = []
-    sensors.append(WinkSmokeDetector(item, api_interface))
-    sensors.append(WinkCoDetector(item, api_interface))
+    sensors = [WinkSmokeDetector(item, api_interface),
+               WinkCoDetector(item, api_interface)]
     if item.get("manufacturer_device_model") == "nest":
         sensors.append(WinkSmokeSeverity(item, api_interface))
         sensors.append(WinkCoSeverity(item, api_interface))
